#!/bin/bash

# main_toolkit_launch.sh

export TOOLKIT=/TOOLKIT
export NFS_MAIN=/mnt/nfs
export HWDISC_FILE=/TOOLKIT/hwdisc.dat
export SERVERID=
export BOOTDEVNODE=

cd ${TOOLKIT}
. toolkit_functions

echo "*** MAIN TOOLKIT LAUNCH ***"
cd ${TOOLKIT}

# copy over utilities
echo "copying over utilites from NFS share"
cp -a ${NFS_MAIN}/utilities/* ${TOOLKIT}
cp -a ${NFS_MAIN}/scripts/* ${TOOLKIT}

# early dropout
read_break

# run hwdisc the first time to get Server ID
./hwdisc3 -f${HWDISC_FILE}
clear
# call function to get ${SERVERID}
export `./hwquery ${HWDISC_FILE} allboards.xml SERVERID=SystemId | sed 's/=.*E11\(.*\)/=\1/g'`;
echo "Server ID: ${SERVERID}"

# copy down datafiles based upon system id
cp -a ${NFS_MAIN}/data_files/${SERVERID}* ${TOOLKIT}

# copy down scripts based upon system id
cp -a ${NFS_MAIN}/scripts/${SERVERID}.sh ${TOOLKIT}


if [ -e ./${SERVERID}.sh ]; then
	REPLY=
	echo "If you want to execute server specific script "${SERVERID}.sh", press <enter>"
	echo "If you want to continue toolkit without running server specific script, type a non-blank character and press <enter>"
	read REPLY
	if [ -z ${REPLY} ]; then
		./${SERVERID}.sh
	fi 
else
	echo "No server specific script "${SERVERID}.sh" found."
fi

sleep 1s

echo ""
echo "Loading modules for hardware"
./load_modules.sh

# rerun hardware discovery 
echo ""
echo "Rerun hardware discovery"

sleep 1s
./hwdisc3 -f${HWDISC_FILE}

# get boot dev node from hwdisc-3.dat
export `./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`
echo "BOOTDEVNODE="${BOOTDEVNODE}

if [ -z ${BOOTDEVNODE} ]; then
	echo "MISSING boot device dev node. Check that the drivers are loaded."
	exec /bin/bash
fi

make_sssd ${BOOTDEVNODE}
clear
ls -al /dev/sssd*

OS_choice=
while [ -z ${OS_choice} ]; do

	echo "Type [linux] for linux install"
	echo "Type [win] for windows install"
	echo "Type [bash] for bash prompt"
	echo -n "choice: "
	read OS_choice

	case ${OS_choice} in

		linux )	${TOOLKIT}/run_linux_unattended.sh ;;

		win )	${TOOLKIT}/run_windows_unattended.sh ;;
		
		bash )	exec /bin/bash ;;	

		* )	echo "Invalid Selection"
			OS_choice= ;;

	esac
done 

echo "Ready To Reboot"
read_break

./reboot c:

exec /bin/bash
